@@ -57,11 +57,42 @@ def path2uid(context, link):
 @implementer(IFieldDeserializer)
 @adapter(IJSONField, IBlocks, IBrowserRequest)
 class BlocksJSONFieldDeserializer(DefaultFieldDeserializer):
+    def _transform(self, blocks):
+        for id, block_value in blocks.items():
+            self.handle_subblocks(block_value)
+            block_type = block_value.get("@type", "")
+            handlers = []
+            for h in subscribers(
+                (self.context, self.request), IBlockFieldDeserializationTransformer
+            ):
+                if h.block_type == block_type or h.block_type is None:
+                    h.blockid = id
+                    handlers.append(h)
+
+            for handler in sorted(handlers, key=lambda h: h.order):
+                block_value = handler(block_value)
+
+            blocks[id] = block_value
+
+        return blocks
+
+    def handle_subblocks(self, block_value):
+        if "data" in block_value:
+            if isinstance(block_value["data"], dict):
+                if "blocks" in block_value["data"]:
+                    block_value["data"]["blocks"] = self._transform(
+                        block_value["data"]["blocks"]
+                    )
+
+        if "blocks" in block_value:
+            block_value["blocks"] = self._transform(block_value["blocks"])
+
     def __call__(self, value):
         value = super(BlocksJSONFieldDeserializer, self).__call__(value)
 
         if self.field.getName() == "blocks":
             for id, block_value in value.items():
+                self.handle_subblocks(block_value)
                 block_type = block_value.get("@type", "")
 
                 handlers = []
@@ -70,6 +101,7 @@ class BlocksJSONFieldDeserializer(DefaultFieldDeserializer):
                     IBlockFieldDeserializationTransformer,
                 ):
                     if h.block_type == block_type or h.block_type is None:
+                        h.blockid = id
                         handlers.append(h)
 
                 for handler in sorted(handlers, key=lambda h: h.order):
